==> oggcodecs_src_0.63.7755.zip: oggdsf/src/lib/codecs/cmml/libCMMLTagsDotNET/AnchorTag.h <==
/*
   Copyright (C) 2003, 2004 Zentaro Kavanagh

   Copyright (C) 2003, 2004 Commonwealth Scientific and Industrial Research
   Organisation (CSIRO) Australia

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
   are met:

   - Redistributions of source code must retain the above copyright
   notice, this list of conditions and the following disclaimer.

   - Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in the
   documentation and/or other materials provided with the distribution.

   - Neither the name of CSIRO Australia nor the names of its
   contributors may be used to endorse or promote products derived from
   this software without specific prior written permission.

   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
   ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
   LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
   PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE ORGANISATION OR
   CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
   EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
   PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
   PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
   LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
   NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
   SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/
#pragma once

using namespace System;
#pragma managed
#using "libiWrapper.dll"
using namespace illiminable::libiWrapper;

#include "TextFieldTag.h"

#pragma unmanaged
#include <config.h>
#include <C_AnchorTag.h>
#pragma managed


namespace illiminable {
namespace libCMMLTagsDotNET {


	//ORIGINAL CLASS
//	//Derived Classes
//	: public C_TextFieldTag
//{
//public:
//	//Constructors
//	C_AnchorTag(void);
//	virtual ~C_AnchorTag(void);
//
//	//Accessors
//	string cls();
//	string href();
//
//	//Mutators
//	void setCls(string inCls);
//	void setHref(string inHref);
//
//	//Other
//	virtual string toString();



	public __gc class AnchorTag
		: public TextFieldTag
	{
	public:
		AnchorTag(void);
		AnchorTag(C_AnchorTag* inTag);
		virtual ~AnchorTag(void);

		//Accessors
		String* cls();
		String* href();

		//Mutators
		void setCls(String* inCls);
		void setHref(String* inHref);

		//Other
		virtual String* toString();


		C_AnchorTag* getMe();


	};
}
}

==> oggcodecs_src_0.69.8924.zip: oggdsf/src/lib/codecs/cmml/libCMMLTagsDotNET/AnchorTag.h <==
/*
   Copyright (C) 2003, 2004 Zentaro Kavanagh

   Copyright (C) 2003, 2004 Commonwealth Scientific and Industrial Research
   Organisation (CSIRO) Australia

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
   are met:

   - Redistributions of source code must retain the above copyright
   notice, this list of conditions and the following disclaimer.

   - Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in the
   documentation and/or other materials provided with the distribution.

   - Neither the name of CSIRO Australia nor the names of its
   contributors may be used to endorse or promote products derived from
   this software without specific prior written permission.

   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
   ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
   LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
   PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE ORGANISATION OR
   CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
   EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
   PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
   PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
   LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
   NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
   SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/
#pragma once

using namespace System;
#pragma managed
#using "libiWrapper.dll"
using namespace illiminable::libiWrapper;

#include "TextFieldTag.h"

#pragma unmanaged
#include <libCMMLTags/config.h>
#include <libCMMLTags/C_AnchorTag.h>
#pragma managed


namespace illiminable {
namespace libCMMLTagsDotNET {


	//ORIGINAL CLASS
//	//Derived Classes
//	: public C_TextFieldTag
//{
//public:
//	//Constructors
//	C_AnchorTag(void);
//	virtual ~C_AnchorTag(void);
//
//	//Accessors
//	string cls();
//	string href();
//
//	//Mutators
//	void setCls(string inCls);
//	void setHref(string inHref);
//
//	//Other
//	virtual string toString();



	public __gc class AnchorTag
		: public TextFieldTag
	{
	public:
		AnchorTag(void);
		AnchorTag(C_AnchorTag* inTag, bool inDeleteBase);
		virtual ~AnchorTag(void);

		//Accessors
		String* cls();
		String* href();

		//Mutators
		void setCls(String* inCls);
		void setHref(String* inHref);

		//Other
		virtual String* toString();


		C_AnchorTag* getMe();


	};
}
}
